searchData={"items":[{"type":"module","title":"Membrane.WebRTC.SignalingChannel","doc":"Channel for sending WebRTC signaling messages between Membrane elements\nand other WebRTC peers.\n\nThe flow of using the signaling channel is the following:\n- Create it with `new/0`.\n- Register the peer process (the one to send and receive signaling messages)\n  with `register_peer/2`.\n- Pass the signaling channel to `Membrane.WebRTC.Source` or `Membrane.WebRTC.Sink` (this\n  can also be done before the call to `register_peer/2`).\n- Send and receive signaling messages. Messages can be sent by calling `signal/2`.\n  The channel sends `t:message/0` to the peer.","ref":"Membrane.WebRTC.SignalingChannel.html"},{"type":"function","title":"Membrane.WebRTC.SignalingChannel.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Membrane.WebRTC.SignalingChannel.html#child_spec/1"},{"type":"function","title":"Membrane.WebRTC.SignalingChannel.close/1","doc":"","ref":"Membrane.WebRTC.SignalingChannel.html#close/1"},{"type":"type","title":"Membrane.WebRTC.SignalingChannel.ex_webrtc_message/0","doc":"Messages sent and received if `message_format` is `ex_webrtc`.","ref":"Membrane.WebRTC.SignalingChannel.html#t:ex_webrtc_message/0"},{"type":"type","title":"Membrane.WebRTC.SignalingChannel.json_data_message/0","doc":"Messages sent and received if `message_format` is `json_data`.\n\nThe keys and values are the following\n- `%{\"type\" => \"sdp_offer\", \"data\" => data}`, where data is the return value of\n  `ExWebRTC.SessionDescription.to_json/1` or `RTCPeerConnection.create_offer` in the JavaScript API\n- `%{\"type\" => \"sdp_answer\", \"data\" => data}`, where data is the return value of\n  `ExWebRTC.SessionDescription.to_json/1` or `RTCPeerConnection.create_answer` in the JavaScript API\n- `%{\"type\" => \"ice_candidate\", \"data\" => data}`, where data is the return value of\n  `ExWebRTC.ICECandidate.to_json/1` or `event.candidate` from the `RTCPeerConnection.onicecandidate`\n  callback in the JavaScript API.","ref":"Membrane.WebRTC.SignalingChannel.html#t:json_data_message/0"},{"type":"type","title":"Membrane.WebRTC.SignalingChannel.message/0","doc":"Messages sent by the signaling channel to the peer.","ref":"Membrane.WebRTC.SignalingChannel.html#t:message/0"},{"type":"type","title":"Membrane.WebRTC.SignalingChannel.message_content/0","doc":"Messages that the peer sends with `signal/2` and receives in `t:message/0`.\n\nIf the `message_format` of the peer is `ex_webrtc` (default), they should be\n`t:ex_webrtc_message/0`.\nIf the `message_format` is `json_data`, they should be `t:json_data_message/0`.\n\nThe `message_format` of the peer can be set in `register_peer/2`.","ref":"Membrane.WebRTC.SignalingChannel.html#t:message_content/0"},{"type":"function","title":"Membrane.WebRTC.SignalingChannel.new/0","doc":"","ref":"Membrane.WebRTC.SignalingChannel.html#new/0"},{"type":"function","title":"Membrane.WebRTC.SignalingChannel.register_peer/2","doc":"Registers a process as a peer, so that it can send and receive signaling messages.\n\nOptions:\n- `pid` - pid of the peer, `self()` by default\n- `message_format` - `:ex_webrtc` by default, see `t:message_content/0`\n\nSee the moduledoc for details.","ref":"Membrane.WebRTC.SignalingChannel.html#register_peer/2"},{"type":"function","title":"Membrane.WebRTC.SignalingChannel.signal/3","doc":"Sends a signaling message to the channel.\n\nThe calling process must be previously registered with `register_peer/2`.\nSee the moduledoc for details.","ref":"Membrane.WebRTC.SignalingChannel.html#signal/3"},{"type":"type","title":"Membrane.WebRTC.SignalingChannel.t/0","doc":"","ref":"Membrane.WebRTC.SignalingChannel.html#t:t/0"},{"type":"module","title":"Membrane.WebRTC.SimpleWebSocketServer","doc":"A simple WebSocket server spawned by `Membrane.WebRTC.Source`\nand `Membrane.WebRTC.Sink`. It accepts a single connection\nand passes the messages between the client and a Membrane\nelement.\n\nThe messages sent and received by the server are JSON-encoded\n`t:Membrane.WebRTC.SignalingChannel.json_data_message/0`.\nAdditionally, the server sends a `{type: \"keep_alive\", data: \"\"}`\nmessages to prevent the WebSocket from being closed.\n\nExamples of configuring and interacting with the server can\nbe found in the `examples` directory.","ref":"Membrane.WebRTC.SimpleWebSocketServer.html"},{"type":"type","title":"Membrane.WebRTC.SimpleWebSocketServer.options/0","doc":"Options for the server.\n\nThe port is required, while the IP address defaults to `{127, 0, 0, 1}`.","ref":"Membrane.WebRTC.SimpleWebSocketServer.html#t:options/0"},{"type":"function","title":"Membrane.WebRTC.SimpleWebSocketServer.validate_options!/1","doc":"","ref":"Membrane.WebRTC.SimpleWebSocketServer.html#validate_options!/1"},{"type":"module","title":"Membrane.WebRTC.Sink","doc":"Membrane Bin that allows sending audio and video tracks via WebRTC.\n\nIt sends an SDP offer and expects an answer during initialization and\neach time when new tracks are added. For more information about signaling,\nsee the `signaling` option.\n\nBefore connecting pads, each audio and video track has to be negotiated.\nTracks passed via `tracks` option are negotiated during initialization.\nYou can negotiate more tracks by sending `t:add_tracks/0` notification\nand waiting for `t:new_tracks/0` notification reply.\n\nWhen the tracks are negotiated, pads can be linked. The pad either\nhas to have a `kind` option set or its id has to match the id of\nthe track received in `t:new_tracks/0` notification.","ref":"Membrane.WebRTC.Sink.html"},{"type":"module","title":"Bin options - Membrane.WebRTC.Sink","doc":"Passed via struct `t:Membrane.WebRTC.Sink.t/0`\n\n- `signaling`  \n\n  ```\n  SignalingChannel.t() | {:whip, whip_options} | {:websocket, SimpleWebSocketServer.options()}\n  ```\n  \n  ***Required***  \n  Channel for passing WebRTC signaling messages (SDP and ICE).\n  Either:\n  - `Membrane.WebRTC.SignalingChannel` - See its docs for details.\n  - `{:whip, options}` - Acts as a WHIP client, see `t:whip_options/0` for details.\n  - `{:websocket, options}` - Spawns Membrane.WebRTC.SimpleWebSocketServer,\n  see there for details.\n\n\n- `tracks`  \n\n  ```\n  [:audio | :video]\n  ```\n  \n  Default value: `[:audio, :video]`  \n  Tracks to be negotiated. By default one audio and one video track\n  is negotiated, meaning that at most one audio and one video can be\n  sent.\n\n\n\n- `video_codec`  \n\n  ```\n  :vp8 | :h264 | [:vp8 | :h264]\n  ```\n  \n  Default value: `[:vp8, :h264]`  \n  Video codecs, that Membrane.WebRTC.Sink will try to negotiatie in SDP\n  message exchange. Even if `[:vp8, :h264]` is passed to this option, there\n  is a chance, that one of these codecs won't be approved by the second\n  WebRTC peer.\n  \n  After SDP messages exchange, Membrane.WebRTC.Sink will send a parent\n  notification `{:new_tracks, tracks}`, where every track in `tracks`\n  contains info about supported codecs.\n\n\n\n- `ice_servers`  \n\n  ```\n  [ExWebRTC.PeerConnection.Configuration.ice_server()]\n  ```\n  \n  Default value: `[%{urls: \"stun:stun.l.google.com:19302\"}]`  \n  \n\n\n\n- `payload_rtp`  \n\n  ```\n  boolean()\n  ```\n  \n  Default value: `true`","ref":"Membrane.WebRTC.Sink.html#module-bin-options"},{"type":"module","title":"Pads - Membrane.WebRTC.Sink","doc":"### `:input`\n\nAccepted formats:\n```\n%Membrane.H264{alignment: :nalu}\n```\n```\n%Membrane.RemoteStream{content_format: Membrane.VP8}\n```\n```\nMembrane.Opus\n```\n```\nMembrane.RTP\n```\n\nDirection: | `:input`\nAvailability: | `:on_request`\nPad options:\n\n- `kind`  \n\n  ```\n  :audio | :video | nil\n  ```\n  \n  Default value: `nil`  \n  When set, the pad is associated with the first negotiated track\n  of the given kind. See the moduledoc for details.","ref":"Membrane.WebRTC.Sink.html#module-pads"},{"type":"type","title":"Membrane.WebRTC.Sink.add_tracks/0","doc":"Notification that should be sent to the bin to negotiate new tracks.\n\nSee the moduledoc for details.","ref":"Membrane.WebRTC.Sink.html#t:add_tracks/0"},{"type":"type","title":"Membrane.WebRTC.Sink.input_pad_opts/0","doc":"Options for pad `:input`","ref":"Membrane.WebRTC.Sink.html#t:input_pad_opts/0"},{"type":"type","title":"Membrane.WebRTC.Sink.new_tracks/0","doc":"Notification sent when new tracks are negotiated.\n\nSee the moduledoc for details.","ref":"Membrane.WebRTC.Sink.html#t:new_tracks/0"},{"type":"function","title":"Membrane.WebRTC.Sink.options/0","doc":"Returns description of options available for this module","ref":"Membrane.WebRTC.Sink.html#options/0"},{"type":"type","title":"Membrane.WebRTC.Sink.t/0","doc":"Struct containing options for `Membrane.WebRTC.Sink`","ref":"Membrane.WebRTC.Sink.html#t:t/0"},{"type":"type","title":"Membrane.WebRTC.Sink.whip_options/0","doc":"WHIP client options\n\n- `uri` - Address of the WHIP server (HTTP/HTTPS)\n- `token` - WHIP token, defaults to an empty string","ref":"Membrane.WebRTC.Sink.html#t:whip_options/0"},{"type":"module","title":"Membrane.WebRTC.Source","doc":"Membrane Bin that allows receiving audio and video tracks via WebRTC.\n\nIt expects an SDP offer to be sent by the other peer at the beginning\nof playback and each time new tracks are added. For more information\nabout signaling, see the `signaling` option.\n\nPads connected immediately when the bin is created\n(in the same spec `t:Membrane.ChildrenSpec.t/0`) need to have the `kind`\noption set to `:audio` or `:video`. Each of those pads will be associated\nwith the first WebRTC track of the given kind that arrives.\n\nWhen a WebRTC tracks arrive and there's no pad to link them to,\nthe `t:new_tracks/0` notification is sent. Then, the corresponding pads\nshould be linked - the id of each pad should match one of the track ids.","ref":"Membrane.WebRTC.Source.html"},{"type":"module","title":"Bin options - Membrane.WebRTC.Source","doc":"Passed via struct `t:Membrane.WebRTC.Source.t/0`\n\n- `signaling`  \n\n  ```\n  SignalingChannel.t() | {:whip, whip_options()} | {:websocket, SimpleWebSocketServer.options()}\n  ```\n  \n  ***Required***  \n  Channel for passing WebRTC signaling messages (SDP and ICE).\n  Either:\n  - `Membrane.WebRTC.SignalingChannel` - See its docs for details.\n  - `{:whip, options}` - Starts a WHIP server, see `t:whip_options/0` for details.\n  - `{:websocket, options}` - Spawns Membrane.WebRTC.SimpleWebSocketServer,\n  see there for details.\n\n\n- `allowed_video_codecs`  \n\n  ```\n  :vp8 | :h264 | [:vp8 | :h264]\n  ```\n  \n  Default value: `:vp8`  \n  Specifies, which video codecs can be accepted by the source during the SDP\n  negotiaion.\n  \n  Either `:vp8`, `:h264` or a list containing both options.\n  \n  Event if it is set to `[:h264, :vp8]`, the source will negotiate at most\n  one video codec. Negotiated codec can be deduced from\n  `{:negotiated_video_codecs, codecs}` notification sent to the parent.\n  \n  If prefer to receive one video codec over another, but you are still able\n  to handle both of them, use `:preferred_video_codec` option.\n  \n  By default only `:vp8`.\n\n\n\n- `preferred_video_codec`  \n\n  ```\n  :vp8 | :h264\n  ```\n  \n  Default value: `:vp8`  \n  Specyfies, which video codec will be preferred by the source, if both of\n  them will be available.\n  \n  Usage of this option makes sense only if there are at least 2 codecs\n  specified in the `:allowed_video_codecs` option.\n  \n  Defaults to `:vp8`.\n\n\n\n- `keyframe_interval`  \n\n  ```\n  Membrane.Time.t() | nil\n  ```\n  \n  Default value: `nil`  \n  If set, a keyframe will be requested as often as specified on each video\n  track.\n\n\n\n- `ice_servers`  \n\n  ```\n  [ExWebRTC.PeerConnection.Configuration.ice_server()]\n  ```\n  \n  Default value: `[%{urls: \"stun:stun.l.google.com:19302\"}]`  \n  \n\n\n\n- `depayload_rtp`  \n\n  ```\n  boolean()\n  ```\n  \n  Default value: `true`  \n  \n\n\n\n- `sdp_candidates_timeout`  \n\n  ```\n  Membrane.Time.t()\n  ```\n  \n  Default value: `1000000000`","ref":"Membrane.WebRTC.Source.html#module-bin-options"},{"type":"module","title":"Pads - Membrane.WebRTC.Source","doc":"### `:output`\n\nAccepted formats:\n```\nMembrane.H264\n```\n```\n%Membrane.RemoteStream{content_format: Membrane.VP8}\n```\n```\n%Membrane.RemoteStream{content_format: Membrane.Opus}\n```\n```\nMembrane.RTP\n```\n\nDirection: | `:output`\nAvailability: | `:on_request`\nPad options:\n\n- `kind`  \n\n  ```\n  any\n  ```\n  \n  Default value: `nil`","ref":"Membrane.WebRTC.Source.html#module-pads"},{"type":"type","title":"Membrane.WebRTC.Source.new_tracks/0","doc":"Notification sent when new tracks arrive.\n\nSee moduledoc for details.","ref":"Membrane.WebRTC.Source.html#t:new_tracks/0"},{"type":"function","title":"Membrane.WebRTC.Source.options/0","doc":"Returns description of options available for this module","ref":"Membrane.WebRTC.Source.html#options/0"},{"type":"type","title":"Membrane.WebRTC.Source.output_pad_opts/0","doc":"Options for pad `:output`","ref":"Membrane.WebRTC.Source.html#t:output_pad_opts/0"},{"type":"type","title":"Membrane.WebRTC.Source.t/0","doc":"Struct containing options for `Membrane.WebRTC.Source`","ref":"Membrane.WebRTC.Source.html#t:t/0"},{"type":"type","title":"Membrane.WebRTC.Source.whip_options/0","doc":"Options for WHIP server input.\n\nThe server accepts a single connection and the stream is received by this source. The options are:\n\n- `token` - either expected WHIP token or a function returning true if the token is valid, otherwise false\n- `serve_static` - make WHIP server also serve static content, such as an HTML page under `/static` endpoint\n- Any of `t:Bandit.options/0` - in particular `ip` and `port`\n\nTo handle multiple connections and have more control over the server, see `Membrane.WebRTC.WhipServer`.","ref":"Membrane.WebRTC.Source.html#t:whip_options/0"},{"type":"module","title":"Membrane.WebRTC.WhipClient","doc":"WebRTC WHIP Client.\n\nAccepts the following options:\n- `uri` - address of a WHIP server\n- `signaling` - the signaling channel - pass the same channel to `Membrane.WebRTC.Sink`\n  to connect it with the WHIP client\n- `token` - token to authenticate in the server, defaults to an empty string","ref":"Membrane.WebRTC.WhipClient.html"},{"type":"function","title":"Membrane.WebRTC.WhipClient.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Membrane.WebRTC.WhipClient.html#child_spec/1"},{"type":"function","title":"Membrane.WebRTC.WhipClient.start_link/1","doc":"","ref":"Membrane.WebRTC.WhipClient.html#start_link/1"},{"type":"module","title":"Membrane.WebRTC.WhipServer","doc":"Server accepting WHIP connections.\n\nAccepts the following options:\n\n- `handle_new_client` - function that accepts the client token and returns either\n  the signaling channel to negotiate the connection or error to reject it. The signaling\n  channel can be passed to `Membrane.WebRTC.Source`.\n- `serve_static` - path to static assets that should be served along with WHIP,\n  under a `/static` endpoint. Useful to serve HTML assets. If set to `false` (default),\n  no static assets are served\n- Any of `t:Bandit.options/0` - Bandit configuration","ref":"Membrane.WebRTC.WhipServer.html"},{"type":"function","title":"Membrane.WebRTC.WhipServer.child_spec/1","doc":"","ref":"Membrane.WebRTC.WhipServer.html#child_spec/1"},{"type":"type","title":"Membrane.WebRTC.WhipServer.option/0","doc":"","ref":"Membrane.WebRTC.WhipServer.html#t:option/0"},{"type":"function","title":"Membrane.WebRTC.WhipServer.start_link/1","doc":"","ref":"Membrane.WebRTC.WhipServer.html#start_link/1"},{"type":"module","title":"Membrane.WebRTC.WhipServer.Router","doc":"WHIP router pluggable to a plug pipeline.\n\nAccepts the same options as `Membrane.WebRTC.WhipServer`.","ref":"Membrane.WebRTC.WhipServer.Router.html"},{"type":"module","title":"Example - Membrane.WebRTC.WhipServer.Router","doc":"```\ndefmodule Router do\n  use Plug.Router\n\n  plug(Plug.Logger)\n  plug(Plug.Static, at: \"/static\", from: \"assets\")\n  plug(:match)\n  plug(:dispatch)\n\n  forward(\n    \"/whip\",\n    to: Membrane.WebRTC.WhipServer.Router,\n    handle_new_client: &__MODULE__.handle_new_client/1\n  )\n\n  def handle_new_client(token) do\n    validate_token!(token)\n    signaling = Membrane.WebRTC.SignalingChannel.new()\n    # pass the signaling channel to a pipeline\n    {:ok, signaling}\n  end\nend\n\nBandit.start_link(plug: Router, ip: any)\n```","ref":"Membrane.WebRTC.WhipServer.Router.html#module-example"},{"type":"extras","title":"Membrane WebRTC Plugin","doc":"# Membrane WebRTC Plugin\n\n[![Hex.pm](https://img.shields.io/hexpm/v/membrane_webrtc_plugin.svg)](https://hex.pm/packages/membrane_webrtc_plugin)\n[![API Docs](https://img.shields.io/badge/api-docs-yellow.svg?style=flat)](https://hexdocs.pm/membrane_webrtc_plugin)\n[![CircleCI](https://circleci.com/gh/membraneframework/membrane_webrtc_plugin.svg?style=svg)](https://circleci.com/gh/membraneframework/membrane_webrtc_plugin)\n\nMembrane Plugin for sending and receiving streams via WebRTC. It's based on [ex_webrtc](https://github.com/elixir-webrtc/ex_webrtc).\n\nIt's a part of the [Membrane Framework](https://membrane.stream).","ref":"readme.html"},{"type":"extras","title":"Installation - Membrane WebRTC Plugin","doc":"The package can be installed by adding `membrane_webrtc_plugin` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:membrane_webrtc_plugin, \"~> 0.23.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Membrane WebRTC Plugin","doc":"The `examples` directory shows how to send and receive streams from a web browser.","ref":"readme.html#usage"},{"type":"extras","title":"Copyright and License - Membrane WebRTC Plugin","doc":"Copyright 2020, [Software Mansion](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane_webrtc_plugin)\n\n[![Software Mansion](https://logo.swmansion.com/logo?color=white&variant=desktop&width=200&tag=membrane-github)](https://swmansion.com/?utm_source=git&utm_medium=readme&utm_campaign=membrane_webrtc_plugin)\n\nLicensed under the [Apache License, Version 2.0](LICENSE)","ref":"readme.html#copyright-and-license"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright 2020 Software Mansion\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}